﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;

namespace DataModel
{
    public class Character
    {
        public string Name { get; set; }
        public Vector2 Position { get; set; }
        public List<Animation> Animations { get; set; }

        [ContentSerializerIgnore]
        public Animation CurrentAnimation { get { return Animations[animationIndex]; } }
        [ContentSerializerIgnore]
        public Dictionary<string, Texture2D> Textures { get; set; }

        int animationIndex = 0;

        public Character()
        {
            Animations = new List<Animation>();
            Position = new Vector2(300, 400);
        }

        public void NextAnim()
        {
            animationIndex++;
            if (animationIndex >= Animations.Count)
                animationIndex = 0;
        }

        protected void StartAnimation(string name)
        {
            if (name == CurrentAnimation.Name)
                return;

            for(int i=0; i<Animations.Count; i++)
            {
                if (Animations[i].Name == name)
                {
                    animationIndex = i;
                    CurrentAnimation.Reset();
                }
            }
        }

        public void Update(GameTime gameTime)
        {
            CurrentAnimation.Update(gameTime);
        }

        public void Draw(GameTime gameTime, SpriteBatch spriteBatch)
        {
            spriteBatch.Draw(Textures[CurrentAnimation.Asset], Position, 
                CurrentAnimation.CurrentFrame.Rectangle, Color.White);
        }
    }
}
